# Table of Contents

- [key-attributes-for-application-portfolio-assessment](<./key-attributes-for-application-portfolio-assessment.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Key Attributes for Application Portfolio Assessment](<./Key-Attributes-for-Application-Portfolio-Assessment.md>)
  - [Lifecycle](<./Key-Attributes-for-Application-Portfolio-Assessment/Lifecycle.md>)
  - [Business Criticality](<./Key-Attributes-for-Application-Portfolio-Assessment/Business-Criticality.md>)
  - [Functional Fit](<./Key-Attributes-for-Application-Portfolio-Assessment/Functional-Fit.md>)
  - [Technical Fit](<./Key-Attributes-for-Application-Portfolio-Assessment/Technical-Fit.md>)
  - [Quality Seal](<./Key-Attributes-for-Application-Portfolio-Assessment/Quality-Seal.md>)
  - [Was this page helpful?](<./Key-Attributes-for-Application-Portfolio-Assessment/Was-this-page-helpful.md>)
